Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(416)

Unified Diff: third_party/WebKit/Source/devtools/front_end/components/Linkifier.js

Issue 2156523003: [DevTools] Fix links for JSFrame records in timeline (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Created 4 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: third_party/WebKit/Source/devtools/front_end/components/Linkifier.js
diff --git a/third_party/WebKit/Source/devtools/front_end/components/Linkifier.js b/third_party/WebKit/Source/devtools/front_end/components/Linkifier.js
index c1c0279ca26fc9e1d7a8b630dcfa68e2d673ce04..7e7a7c9a9bc3091947f1607d9b03062ac8391c2a 100644
--- a/third_party/WebKit/Source/devtools/front_end/components/Linkifier.js
+++ b/third_party/WebKit/Source/devtools/front_end/components/Linkifier.js
@@ -213,9 +213,9 @@ WebInspector.Linkifier.prototype = {
* @param {string=} classes
* @return {!Element}
*/
- linkifyConsoleCallFrameForTimeline: function(target, callFrame, classes)
+ linkifyConsoleCallFrameForTracing: function(target, callFrame, classes)
{
// TODO(kozyatinskiy): remove this when Profilers will migrate to 0-based lineNumber and columnNumber.
alph 2016/07/18 19:49:21 I's prefer that once an object is claimed to be a
kozy 2016/07/18 22:57:22 Acknowledged.
return this.linkifyScriptLocation(target, callFrame.scriptId, callFrame.url, callFrame.lineNumber - 1, callFrame.columnNumber - 1, classes);
@@ -213,9 +213,9 @@ WebInspector.Linkifier.prototype = {
{
- // TODO(kozyatinskiy): remove this when Profilers will migrate to 0-based lineNumber and columnNumber.
+ // TODO(kozyatinskiy): remove this when tracing will migrate to 0-based lineNumber and columnNumber.
alph 2016/07/18 19:49:21 I's prefer that once an object is claimed to be a
kozy 2016/07/18 22:57:22 Acknowledged.
},

Powered by Google App Engine
This is Rietveld 408576698